==> hylafax_4.3.1.orig.tar.gz: hylafax-4.3.1/faxd/Class20.h <==
/*	$Id: Class20.h,v 1.2 1999/06/13 07:41:01 robert Exp $ */
/*
 * Copyright (c) 1990-1996 Sam Leffler
 * Copyright (c) 1991-1996 Silicon Graphics, Inc.
 * HylaFAX is a trademark of Silicon Graphics
 *
 * Permission to use, copy, modify, distribute, and sell this software and 
 * its documentation for any purpose is hereby granted without fee, provided
 * that (i) the above copyright notices and this permission notice appear in
 * all copies of the software and related documentation, and (ii) the names of
 * Sam Leffler and Silicon Graphics may not be used in any advertising or
 * publicity relating to the software without the specific, prior written
 * permission of Sam Leffler and Silicon Graphics.
 * 
 * THE SOFTWARE IS PROVIDED "AS-IS" AND WITHOUT WARRANTY OF ANY KIND, 
 * EXPRESS, IMPLIED OR OTHERWISE, INCLUDING WITHOUT LIMITATION, ANY 
 * WARRANTY OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.  
 * 
 * IN NO EVENT SHALL SAM LEFFLER OR SILICON GRAPHICS BE LIABLE FOR
 * ANY SPECIAL, INCIDENTAL, INDIRECT OR CONSEQUENTIAL DAMAGES OF ANY KIND,
 * OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
 * WHETHER OR NOT ADVISED OF THE POSSIBILITY OF DAMAGE, AND ON ANY THEORY OF 
 * LIABILITY, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE 
 * OF THIS SOFTWARE.
 */
#ifndef _CLASS20_
#define	_CLASS20_
/*
 * Class 2.0-style Modem Driver (TIA/EIA-592).
 */
#include "Class2.h"

class Class20Modem : public Class2Modem {
protected:
// transmission support
    bool	sendPage(TIFF* tif, u_int pageChop);
    bool	pageDone(u_int ppm, u_int& ppr);

    void	abortDataTransfer();
// reception support
    int		nextByte();
// miscellaneous
    virtual ATResponse atResponse(char* buf, long ms = 30*1000);
public:
    Class20Modem(FaxServer&, const ModemConfig&);
    virtual ~Class20Modem();
};
#endif /* _CLASS20_ */

==> hylafax-6.0.2.tar.gz: hylafax-6.0.2/faxd/Class20.h <==
/*	$Id: Class20.h,v 1.3 2008/10/01 20:06:52 aidan Exp $ */
/*
 * Copyright (c) 1990-1996 Sam Leffler
 * Copyright (c) 1991-1996 Silicon Graphics, Inc.
 * HylaFAX is a trademark of Silicon Graphics
 *
 * Permission to use, copy, modify, distribute, and sell this software and 
 * its documentation for any purpose is hereby granted without fee, provided
 * that (i) the above copyright notices and this permission notice appear in
 * all copies of the software and related documentation, and (ii) the names of
 * Sam Leffler and Silicon Graphics may not be used in any advertising or
 * publicity relating to the software without the specific, prior written
 * permission of Sam Leffler and Silicon Graphics.
 * 
 * THE SOFTWARE IS PROVIDED "AS-IS" AND WITHOUT WARRANTY OF ANY KIND, 
 * EXPRESS, IMPLIED OR OTHERWISE, INCLUDING WITHOUT LIMITATION, ANY 
 * WARRANTY OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.  
 * 
 * IN NO EVENT SHALL SAM LEFFLER OR SILICON GRAPHICS BE LIABLE FOR
 * ANY SPECIAL, INCIDENTAL, INDIRECT OR CONSEQUENTIAL DAMAGES OF ANY KIND,
 * OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
 * WHETHER OR NOT ADVISED OF THE POSSIBILITY OF DAMAGE, AND ON ANY THEORY OF 
 * LIABILITY, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE 
 * OF THIS SOFTWARE.
 */
#ifndef _CLASS20_
#define	_CLASS20_
/*
 * Class 2.0-style Modem Driver (TIA/EIA-592).
 */
#include "Class2.h"

class Class20Modem : public Class2Modem {
protected:
// transmission support
    bool	sendPage(TIFF* tif, u_int pageChop, bool cover);
    bool	pageDone(u_int ppm, u_int& ppr);

    void	abortDataTransfer();
// reception support
    int		nextByte();
// miscellaneous
    virtual ATResponse atResponse(char* buf, long ms = 30*1000);
public:
    Class20Modem(FaxServer&, const ModemConfig&);
    virtual ~Class20Modem();
};
#endif /* _CLASS20_ */
